@@ -1,9 +1,10 @@
 from abc import ABC, abstractmethod
-from enum import Enum
 from os import PathLike
 from pathlib import PurePosixPath
 from textwrap import indent
 
+from enum import Enum
+
 INDENTATION = '  '
 
 
@@ -41,7 +42,7 @@ class RemapMethod(Enum):
 
 class ModelMeshEntry(ABC):
     def __init__(self, mesh_type: ModelType, filename: PathLike = None):
-        if not isinstance(filename, PurePosixPath):
+        if filename is not None and not isinstance(filename, PurePosixPath):
             filename = PurePosixPath(filename)
 
         self.mesh_type = mesh_type
@@ -49,7 +50,7 @@ class ModelMeshEntry(ABC):
 
     def __str__(self) -> str:
         if self.filename is not None:
-            directory = self.filename.parent
+            directory = self.filename.parent.as_posix()
             name = self.filename.name
         else:
             directory = ''
@@ -219,10 +220,13 @@ class ModelEntry(ConfigurationEntry, SequenceEntry):
     def from_string(cls, string: str, **kwargs) -> 'ModelEntry':
         lines = string.splitlines()
 
-        model_type, name = (value.strip() for value in lines[0].split('_model:'))
+        parsed_model_type, parsed_name = (value.strip() for value in lines[0].split('_model:'))
+        parsed_model_type = ModelType(parsed_model_type)
 
-        assert ModelType(model_type) == cls.model_type
-        assert name == cls.name
+        if hasattr(cls, 'model_type'):
+            assert parsed_model_type == cls.model_type
+        if hasattr(cls, 'name'):
+            assert parsed_name == cls.name
 
         start_processor, end_processor = [
             int(entry) for entry in lines[1].split('_petlist_bounds:')[-1].strip().split()
@@ -233,15 +237,14 @@ class ModelEntry(ConfigurationEntry, SequenceEntry):
             key, value = (value.strip() for value in attribute_line.split('='))
             attributes[key] = value
 
-        if issubclass(cls, ModelMeshEntry):
-            if 'filename' not in kwargs:
-                kwargs['filename'] = None
+        instance = cls(processors=end_processor + 1 - start_processor, **attributes, **kwargs,)
 
-        return cls(
-            processors=end_processor + 1 - start_processor,
-            **attributes,
-            **kwargs,
-        )
+        if not hasattr(cls, 'model_type'):
+            instance.model_type = parsed_model_type
+        if not hasattr(cls, 'name'):
+            instance.name = parsed_name
+
+        return instance
 
 
 class ConnectionEntry(SequenceEntry):
@@ -286,11 +289,7 @@ class ConnectionEntry(SequenceEntry):
         target_model.name = target
         target_model.model_type = ModelType(target)
 
-        return cls(
-            source=source_model,
-            target=target_model,
-            method=method,
-        )
+        return cls(source=source_model, target=target_model, method=method,)
 
 
 class MediatorEntry(ModelEntry):
@@ -318,7 +317,7 @@ class MediationFunctionEntry(SequenceEntry):
     @classmethod
     def from_string(cls, string: str) -> 'MediationFunctionEntry':
         mediator_name, function_name = string.split()
-        return cls(name=function_name, mediator=MediatorEntry(mediator_name), )
+        return cls(name=function_name, mediator=MediatorEntry(mediator_name),)
 
 
 class MediationEntry(SequenceEntry):
@@ -398,11 +397,15 @@ class MediationEntry(SequenceEntry):
                     parts = [entry.strip() for entry in line.split('->')]
                     method = None
                     if ':' in parts[-1]:
-                        parts[-1], method = [entry.strip() for entry in parts[-1].split(':remapMethod=')]
+                        parts[-1], method = [
+                            entry.strip() for entry in parts[-1].split(':remapMethod=')
+                        ]
                     if len(parts) == 2:
                         connection = ConnectionEntry.from_string(line)
                     else:
-                        connection = ConnectionEntry(source=parts[0], target=parts[-1], method=method)
+                        connection = ConnectionEntry(
+                            source=parts[0], target=parts[-1], method=method
+                        )
                     connections.append(connection)
                 else:
                     functions.append(MediationFunctionEntry.from_string(line))
